// Persistence of Vision Ray Tracer Scene Description File
// File: hair_ex.pov
// Vers: 3.6.1
// Desc: Topview for Surcoat-Macro 
// Date: 09.02.05 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de
// Last Update: 10.02.05 (dd.mm.yy)

//Required Files
// "sc2hair.inc" - The Surcoat-To-Hair Macros

//Description
//
/*Commandline
+AM2 +A0.1 +R2 +W800 +H640
*/

#include "sc2hair.inc"
//The only two parameters that can be adjusted (aside of customizing
// entire macros, read more about that in the help).
//#declare Sc2Hair_IndividualTexture = 0;

//Set to "on" because the IHairs are placed on a planar +/-y surface. This
//switch adds a random y-rotation rotation to break up the alignment.
#declare Sc2Hair_YSwitch = 1;

global_settings{assumed_gamma 1}
camera{
  location <5,7,-12>
  look_at <0,2.5,0>
}

//Mainlights
light_source{<40,150,210> rgb .3}
light_source{<-40,250,-310> rgb 1}

//Backlight
light_source{
  <-500,350,500>
  rgb <.05,.05,.3>
  shadowless
  parallel point_at <0,0,0>
}

#declare Test_Object = 
  merge{
    box{<-3,0,-3><3,1,3>}
    cylinder{<-2.5,0,-2.5><-2.5,4.01,-2.5>,.5}
    box{<-3,4,-3><3,5,3>}
    sphere{y*6,1}
    cylinder{y*4.5,y*6,1}
  }    

//Gravity and Wind settings
#declare Hair_Gravity = -y;
#declare Hair_Wind = <0,0,0>;
#declare Hair_WindStrength = .7;
//Detail settings
#declare Hair_FixedSteps = on;
#declare Hair_Steps = <8,15>; //<diameter, length>
#declare Hair_BentPerUnit = 60;
//Modify the x:y ratio of the hair
#declare Hair_BaseStretchRatio=1;
#declare Hair_TipStretchRatio=1;

#declare Sc2Hair_IndividualTexture = 1;
//"Sc2Hair_Texture"
//Function:
// Textures a single hair
//Parameters:
// 1. Position/Base of hair
// 2. Original-Normal of hairbase
// 3. Modified-Normal of hairbase
// 4. Length of hair
//Returns:
// Some sort of texture-description
//Notes:
// User-Definable
#macro Sc2Hair_Texture(Position,Original_Normal,Modified_Normal,Length)
  #local _Rgb = (Original_Normal+1)/2;
  texture{pigment{rgb _Rgb}}
#end

//Don't save IHairs to disk, just create a few in the memory
Create_IHairs(4,1,<.04,.01>,<1,1>)

union{
  object{
    //Use the formerly created IHairs
    Sc2Hair_UseCreated("example.smp")
    pigment{rgb <.8,.6,0>}
    finish{specular .8 roughness .005}
  }
  object{Test_Object}
  pigment{rgb x}
}

