// Persistence of Vision Ray Tracer Scene Description File
// File: example_1.pov
// Vers: 3.6.1
// Desc: Orthographic views of the demo-object 
// Date: 09.02.05 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de
// Last Update: 10.02.05 (dd.mm.yy)

//Required Files
// "surcoat.inc" - Surcoat-Macros

//Description
// Renders three orthographic views of the Sample-Object in the first
// three frames. The fourth frame then samples the views and appends
// the data into a single file.

//Important! Render this to TGA using the +ft switch on the commandline,
// or simply run "example_1.ini" to render this scene. POV-Ray also
// needs read-access to the folder in which the images are being saved.

/*Commandline
+w320 +h240 +am2 +a0.3 +r2 +fn +kfi1 +kff4
*/

#include "surcoat.inc"

#declare Surcoat_CellResolution = 2;
#declare Surcoat_CellSamples = 15;

#declare Surcoat_Sample_Offset = .0001;
#declare Sample_Filename = "example"
#declare Sample_Filename_Ending = "smp"

#declare Sample_Object = 
  merge{
    box{<-3,0,-3><3,1,3>}
    cylinder{<-2.5,0,-2.5><-2.5,4.01,-2.5>,.5}
    box{<-3,4,-3><3,5,3>}
    sphere{y*6,1}
  }    

#if (frame_number = 1)
  #declare Surcoat_Sample_Direction = x;
  #declare Surcoat_Sample_Offset = .0001;
  Surcoat_Orthoview(Sample_Object)
#end

#if (frame_number = 2)
  #declare Surcoat_Sample_Direction = y;
  #declare Surcoat_Sample_Offset = .0001;
  Surcoat_Orthoview(Sample_Object)
#end

#if (frame_number = 3)
  #declare Surcoat_Sample_Direction = z;
  #declare Surcoat_Sample_Offset = .0001;
  Surcoat_Orthoview(Sample_Object)
#end

#if (frame_number = 4)
  #declare Surcoat_Debug = on;
  #declare Surcoat_Sample_OverrideDirection = 1;

  //Sample from the different directions
  #declare Surcoat_Topview = pigment{image_map{tga "example_11.tga"}}
  #declare Surcoat_Sample_Direction = x;
  Surcoat_CreateSamples(Sample_Object)
  Surcoat_SaveSurface(concat(Sample_Filename,"1.tmp"))
  #declare Surcoat_Topview = pigment{image_map{tga "example_12.tga"}}
  #declare Surcoat_Sample_Direction = y;
  Surcoat_CreateSamples(Sample_Object)
  Surcoat_SaveSurface(concat(Sample_Filename,"2.tmp"))
  #declare Surcoat_Topview = pigment{image_map{tga "example_13.tga"}}
  #declare Surcoat_Sample_Direction = z;
  Surcoat_CreateSamples(Sample_Object)
  Surcoat_SaveSurface(concat(Sample_Filename,"3.tmp"))

  //Append the samples
  Surcoat_AppendSamples(
    array[3]{
      concat(Sample_Filename,"1.tmp"),
      concat(Sample_Filename,"2.tmp"),
      concat(Sample_Filename,"3.tmp")
    },
    concat(Sample_Filename,".",Sample_Filename_Ending)
  )
  //Emptying the source-files
  #fopen _Delete concat(Sample_Filename,"1.tmp") write
  #fclose _Delete
  #fopen _Delete concat(Sample_Filename,"2.tmp") write
  #fclose _Delete
  #fopen _Delete concat(Sample_Filename,"3.tmp") write
  #fclose _Delete

camera{location <0,0,-6> look_at <0,0,0>}
text{
  ttf "arial.ttf" "Done." .1, <0,0,0> pigment{rgb 1} finish{ambient 1}
  translate x*-1.6
  }
  
#end
