// Persistence of Vision Ray Tracer Scene Description File
// File: process.pov
// Vers: 3.6.1
// Desc: Example to build own sorting algorithm 
// Date: 06.01.05 (dd.mm.yy)
// Auth: Tim Nikias Wenclawiak - www.NoLights.de
// Last Update: 06.01.05 (dd.mm.yy)

//Required Files
// "surcoat.inc"   - Surcoat-Macros
// "example_1.png" - Example Orthographic view

//Description
// An example how to build your own sorting algorithm with
// the given set of macros to ease the usage. There are just
// a few building-blocks:
// Surcoat_SortingFileIO_Begin()
//   -> Needed to initialize the loop
// Surcoat_GetSamle(Position,Normal)
//   -> Loads a sample, you need to declare Position and Normal first,
//      as seen in the example below
// Surcoat_SetSample(Position,Normal)
//   -> Will save the current sample, even with changed Position/Normal
// Surcoat_SortingFileIO_End()
//   -> Closes the sorting process and adds the final data to the
//      macro for further processing

// To actually use your own Sorting-Macro (built with the above
// blocks), use Surcoat_PrepareSorting() to prepare the data for
// sorting, and finally, use Surcoat_SaveSorted("Filename-String")
// to save the sorted samples to disk.

#include "surcoat.inc"

global_settings{
  assumed_gamma 1
}

camera{
  location <3,7,-14>
  look_at <0,3,0>
}
light_source{<100,200,-300> rgb 1}

//Define a macro and use a few simple prepared macros for the
//internal File-I/O. Note that you can choose any name for your
//macro, it is just important to use the supplied macros to
//build the sorting macro.
#macro Surcoat_DropBelow(MinHeight)
  //Macro: Prepare the File I/O
  Surcoat_SortingFileIO_Begin()
  //Loop through all samples, the boolean value is given and
  // taken care of by the supplied macros
  #while (Surcoat_SampleLoop)
    #declare Position = <0,0,0>;
    #declare Normal = <0,0,0>;
    //Macro: Loads a sample
    Surcoat_GetSample(Position,Normal)
    //The following lines should be filled with script which somehow
    //checks the samples, in this example, I'm checking the y-component
    //if its negative.
    #if (Position.y < MinHeight)
      #declare SaveThisSample = false;
    #else
      #declare SaveThisSample = true;
    #end
    //Macro: This will save a sample
    #if (SaveThisSample=true)
      Surcoat_SetSample(Position,Normal)
    #end
  #end
  //Macro: Close the File-I/O and wrap the internal data
  Surcoat_SortingFileIO_End()
#end


//Coat an object, typical low-res settings
#declare Surcoat_Topview = pigment{image_map{png "example_1.png"}}
#declare Surcoat_CellResolution = 2;
#declare Surcoat_CellSamples = 10;

#declare Surcoat_Sample_Direction = -y-x+z;
#declare Surcoat_Sample_MaxDirectionDeviation = 90;
#declare Surcoat_Sample_OverrideDirection = 0;

#declare Test_Object = 
  merge{
    box{<-3,0,-3><3,1,3>}
    cylinder{<-2.5,0,-2.5><-2.5,4.01,-2.5>,.5}
    box{<-3,4,-3><3,5,3>}
    sphere{y*6,1}
    cylinder{y*4.5,y*6,1}
    pigment{rgb x}
  }    

//Samples the object's surface with the given settings
Surcoat_CreateSamples(Test_Object)

Surcoat_PrepareSorting()
Surcoat_DropBelow(2)
Surcoat_SaveSorted("process.tmp")

//Visualizes samples with spheres
union{
  Surcoat_Spheres("process.tmp",.1)
  object{Test_Object}
  pigment{rgb 1}
}
